package
Version:
v0.0.0-...-bbcb601
Opens a new window with list of versions in this module.
Published: Jul 9, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Job information
func New(id, title, location, salary, summary string) *Job
New creates Job
ToSlice makes a slice with attributes of Job
Source Files
¶
Click to show internal directories.
Click to hide internal directories.